@@ -47,8 +47,8 @@ class Constants:
 	IS_WIN32 = 0			  # 0 for Unix (Mac is BSD Unix now.) 1 for Windows (tm)
 
 	if (IS_WIN32):
-		DATA = "data"						 # root of all your data files - can be read-only
-		FILES_DIR = "data\\files"			 # incoming data handler's dir - must be read-write
+		DATA = "..\\data"					 # root of all your data files - can be read-only
+		FILES_DIR = "..\\data\\files"		 # incoming data handler's dir - must be read-write
 		LOG_DIR = FILES_DIR					 # where your log will be written - "." for cgi-bin
 	else:
 		DATA = "../data"					 # root of all your data files - can be read-only
