@@ -42,8 +42,9 @@ class Lib3:
 		stamp = " ".join([tokens[2],tokens[1],year])
 		return stamp
 
-	def form_token(self):
-		return hex(abs(hash(time.time())))[2:]
+	def form_token(self, t=None):
+		if not t: t = time.time()
+		return hex(abs(hash(t)))[2:]
 
 	def get_dict(self, file, key="stamp"):
 		i = 0
@@ -70,13 +71,13 @@ class Lib3:
 				pass
 		return file_dict
 
-	def get_lines(self, file):
+	def get_lines(self, file, keep=True):
 		"""
 		returns f.readlines on file
 		"""
 		try:
 			f = open(file)
-			lines = f.readlines()
+			lines = f.read().splitlines(keep)
 			f.close()
 		except:
 			lines = []
@@ -115,7 +116,7 @@ class Lib3:
 		types = []
 		for line in lines:
 			line = line.strip()
-			if (line != ""):
+			if line:
 				tokens = self.tokens(line,"|")
 				types.append( (tokens[0], site+"."+tokens[1]) )
 		return types
