@@ -137,27 +137,30 @@ class PageMaker:
 		def __read_data(fname):
 			lines = self.lib.get_lines(fname)
 			type = lines[0].strip()
-			data = lines[1:]
+			if type == "#python":
+				data = []
+				def w(text):
+					global data
+					data += (text + "\n").splitlines(1)
+				namespace = globals()
+				namespace["data"] = data
+				namespace["write"] = w
+				if "params" in self.form.keys():
+					namespace["params"] = self.form["params"].value
+				try: execfile(self.fname, namespace)
+				except SystemExit: pass  # in case sys.exit is called
+			else: data = lines[1:]
 			return type, data
 		try:
 			self.fname = dirname+os.sep+name
 			self.title, desc = self.files[name]
 			self.type, data = __read_data(self.fname)
-			if (self.type == "#python"):
-				cmd = "python " + self.fname
-				if ("params" in self.form.keys()):
-					cmd = cmd + " " + self.form["params"].value
-				try:
-					data = os.popen3(cmd)[1].readlines()
-				except:
-					data = data + os.popen3(cmd)[2].readlines()
-				if (self.debug): # this catches some testing exceptions
-					data = data + os.popen3(cmd)[2].readlines()
 			parser = self.PARSERS[self.type](self.lib, self.debug)
 			parsed_data = parser.parse(self.title, desc, data)
 			parsed_data[self.MENU] = self.menu
 		except:
-			return None
+			if self.debug: raise
+			else: return None # this ends in a "not found" mess
 		return parsed_data
 
 	def __get_plate(self, path):
